@@ -1,6 +1,7 @@
 package Foo::Bar::4;
 
 use Moo;
+extends 'Foo::Bar::0';
 
 has 'foo' => (
     is      => 'ro',
@@ -14,4 +15,12 @@ sub BUILDARGS {
     return {@args};
 }
 
+sub BUILD {
+    my ($self) = @_;
+
+    push @Foo::Bar::0::build_order, __PACKAGE__;
+
+    return;
+}
+
 1;
